@@ -1,5 +1,5 @@
 /*
- * ggit-diff.c
+ * ggit-list.c
  * This file is part of libgit2-glib
  *
  * Copyright (C) 2012 - Garrett Regier
@@ -18,12 +18,14 @@
  * along with libgit2-glib. If not, see <http://www.gnu.org/licenses/>.
  */
 
-#include <git2/errors.h>
+#include <git2.h>
 
 #include "ggit-diff.h"
 #include "ggit-diff-delta.h"
 #include "ggit-diff-options.h"
-#include "ggit-diff-range.h"
+#include "ggit-diff-line.h"
+#include "ggit-diff-hunk.h"
+#include "ggit-patch.h"
 #include "ggit-error.h"
 #include "ggit-repository.h"
 
@@ -57,23 +59,20 @@ ggit_diff_file_callback_wrapper (const git_diff_delta *delta,
 
 static gint
 ggit_diff_hunk_callback_wrapper (const git_diff_delta *delta,
-                                 const git_diff_range *range,
-                                 const gchar          *header,
-                                 gsize                 header_len,
+                                 const git_diff_hunk  *hunk,
                                  gpointer              user_data)
 {
 	CallbackWrapperData *data = user_data;
 	GgitDiffDelta *gdelta;
-	GgitDiffRange *grange;
+	GgitDiffHunk *ghunk;
 	gint ret;
 
 	gdelta = _ggit_diff_delta_wrap (delta);
-	grange = _ggit_diff_range_wrap (range);
+	ghunk = _ggit_diff_hunk_wrap (hunk);
 
-	ret = data->hunk_cb (gdelta, grange, header, header_len,
-	                     data->user_data);
+	ret = data->hunk_cb (gdelta, ghunk, data->user_data);
 
-	ggit_diff_range_unref (grange);
+	ggit_diff_hunk_unref (ghunk);
 	ggit_diff_delta_unref (gdelta);
 
 	return ret;
@@ -81,26 +80,30 @@ ggit_diff_hunk_callback_wrapper (const git_diff_delta *delta,
 
 static gint
 ggit_diff_line_callback_wrapper (const git_diff_delta *delta,
-                                 const git_diff_range *range,
-                                 gchar                 line_type,
-                                 const gchar          *content,
-                                 gsize                 content_len,
+                                 const git_diff_hunk  *hunk,
+                                 const git_diff_line  *line,
                                  gpointer              user_data)
 {
 	CallbackWrapperData *data = user_data;
 	GgitDiffDelta *gdelta;
-	GgitDiffRange *grange;
+	GgitDiffHunk *ghunk;
+	GgitDiffLine *gline;
 	gint ret;
 
 	gdelta = _ggit_diff_delta_wrap (delta);
-	grange = range == NULL ? NULL : _ggit_diff_range_wrap (range);
+	ghunk = hunk == NULL ? NULL : _ggit_diff_hunk_wrap (hunk);
+	gline = line == NULL ? NULL : _ggit_diff_line_wrap (line);
 
-	ret = data->line_cb (gdelta, grange, (GgitDiffLineType) line_type,
-	                     content, content_len, data->user_data);
+	ret = data->line_cb (gdelta, ghunk, gline, data->user_data);
 
-	if (grange != NULL)
+	if (gline != NULL)
 	{
-		ggit_diff_range_unref (grange);
+		ggit_diff_line_unref (gline);
+	}
+
+	if (ghunk != NULL)
+	{
+		ggit_diff_hunk_unref (ghunk);
 	}
 
 	ggit_diff_delta_unref (gdelta);
@@ -119,8 +122,8 @@ ggit_diff_init (GgitDiff *self)
 }
 
 GgitDiff *
-_ggit_diff_wrap (git_diff_list *diff,
-                 gboolean       owned)
+_ggit_diff_wrap (git_diff *diff,
+                 gboolean  owned)
 {
 	GgitDiff *gdiff;
 
@@ -130,7 +133,7 @@ _ggit_diff_wrap (git_diff_list *diff,
 	if (owned)
 	{
 		_ggit_native_set_destroy_func (gdiff,
-		                               (GDestroyNotify)git_diff_list_free);
+		                               (GDestroyNotify)git_diff_free);
 	}
 
 	return gdiff;
@@ -158,7 +161,7 @@ ggit_diff_new_tree_to_tree (GgitRepository   *repository,
                             GgitDiffOptions  *diff_options,
                             GError          **error)
 {
-	git_diff_list *diff;
+	git_diff *diff;
 	gint ret;
 
 	g_return_val_if_fail (GGIT_IS_REPOSITORY (repository), NULL);
@@ -205,7 +208,7 @@ ggit_diff_new_tree_to_index (GgitRepository   *repository,
                              GgitDiffOptions  *diff_options,
                              GError          **error)
 {
-	git_diff_list *diff;
+	git_diff *diff;
 	gint ret;
 
 	g_return_val_if_fail (GGIT_IS_REPOSITORY (repository), NULL);
@@ -249,7 +252,7 @@ ggit_diff_new_index_to_workdir (GgitRepository   *repository,
                                 GgitDiffOptions  *diff_options,
                                 GError          **error)
 {
-	git_diff_list *diff;
+	git_diff *diff;
 	gint ret;
 
 	g_return_val_if_fail (GGIT_IS_REPOSITORY (repository), NULL);
@@ -290,7 +293,7 @@ ggit_diff_new_tree_to_workdir (GgitRepository   *repository,
                                GgitDiffOptions  *diff_options,
                                GError          **error)
 {
-	git_diff_list *diff;
+	git_diff *diff;
 	gint ret;
 
 	g_return_val_if_fail (GGIT_IS_REPOSITORY (repository), NULL);
@@ -365,7 +368,7 @@ ggit_diff_foreach (GgitDiff              *diff,
 	CallbackWrapperData wrapper_data;
 	git_diff_file_cb real_file_cb = NULL;
 	git_diff_hunk_cb real_hunk_cb = NULL;
-	git_diff_data_cb real_line_cb = NULL;
+	git_diff_line_cb real_line_cb = NULL;
 
 	g_return_if_fail (GGIT_IS_DIFF (diff));
 	g_return_if_fail (file_cb != NULL && hunk_cb != NULL && line_cb != NULL);
@@ -402,19 +405,21 @@ ggit_diff_foreach (GgitDiff              *diff,
 }
 
 /**
- * ggit_diff_print_compact:
+ * ggit_diff_print:
  * @diff: a #GgitDiff.
+ * @type: a #GgitDiffFormatType.
  * @print_cb: (scope call) (closure user_data): a #GgitDiffLineCallback.
  * @user_data: callback user data.
  * @error: a #GError for error reporting, or %NULL.
  *
- * Iterates over @diff generating text output like "git diff --name-status".
+ * Iterates over @diff generating text output like "git diff".
  */
 void
-ggit_diff_print_compact (GgitDiff              *diff,
-                         GgitDiffLineCallback   print_cb,
-                         gpointer              *user_data,
-                         GError               **error)
+ggit_diff_print (GgitDiff              *diff,
+                 GgitDiffFormatType     type,
+                 GgitDiffLineCallback   print_cb,
+                 gpointer              *user_data,
+                 GError               **error)
 {
 	gint ret;
 	CallbackWrapperData wrapper_data;
@@ -426,9 +431,9 @@ ggit_diff_print_compact (GgitDiff              *diff,
 	wrapper_data.user_data = user_data;
 	wrapper_data.line_cb = print_cb;
 
-	ret = git_diff_print_compact (_ggit_native_get (diff),
-	                              ggit_diff_line_callback_wrapper,
-	                              &wrapper_data);
+	ret = git_diff_print (_ggit_native_get (diff), (git_diff_format_t)type,
+	                      ggit_diff_line_callback_wrapper,
+	                      &wrapper_data);
 
 	if (ret != GIT_OK)
 	{
@@ -437,38 +442,20 @@ ggit_diff_print_compact (GgitDiff              *diff,
 }
 
 /**
- * ggit_diff_print_patch:
+ * ggit_diff_get_num_deltas:
  * @diff: a #GgitDiff.
- * @print_cb: (scope call) (closure user_data): a #GgitDiffLineCallback.
- * @user_data: callback user data.
- * @error: a #GError for error reporting, or %NULL.
  *
- * Iterates over @diff generating text output like "git diff".
- */
-void
-ggit_diff_print_patch (GgitDiff              *diff,
-                       GgitDiffLineCallback   print_cb,
-                       gpointer              *user_data,
-                       GError               **error)
+ * Get the number of deltas in the diff list.
+ *
+ * Returns: the number of deltas.
+ *
+ **/
+gint
+ggit_diff_get_num_deltas (GgitDiff *diff)
 {
-	gint ret;
-	CallbackWrapperData wrapper_data;
+	g_return_val_if_fail (GGIT_IS_DIFF (diff), 0);
 
-	g_return_if_fail (GGIT_IS_DIFF (diff));
-	g_return_if_fail (print_cb != NULL);
-	g_return_if_fail (error == NULL || *error == NULL);
-
-	wrapper_data.user_data = user_data;
-	wrapper_data.line_cb = print_cb;
-
-	ret = git_diff_print_patch (_ggit_native_get (diff),
-	                            ggit_diff_line_callback_wrapper,
-	                            &wrapper_data);
-
-	if (ret != GIT_OK)
-	{
-		_ggit_error_set (error, ret);
-	}
+	return git_diff_num_deltas (_ggit_native_get (diff));
 }
 
 /**
@@ -512,7 +499,7 @@ ggit_diff_blobs (GgitBlob              *old_blob,
 	CallbackWrapperData wrapper_data;
 	git_diff_file_cb real_file_cb = NULL;
 	git_diff_hunk_cb real_hunk_cb = NULL;
-	git_diff_data_cb real_line_cb = NULL;
+	git_diff_line_cb real_line_cb = NULL;
 
 	g_return_if_fail (error == NULL || *error == NULL);
 
@@ -589,7 +576,7 @@ ggit_diff_blob_to_buffer (GgitBlob              *old_blob,
 	CallbackWrapperData wrapper_data;
 	git_diff_file_cb real_file_cb = NULL;
 	git_diff_hunk_cb real_hunk_cb = NULL;
-	git_diff_data_cb real_line_cb = NULL;
+	git_diff_line_cb real_line_cb = NULL;
 
 	g_return_if_fail (error == NULL || *error == NULL);
 
