@@ -148,6 +148,38 @@ ggit_delta_type_get_type (void)
 	return the_type;
 }
 
+GType
+ggit_diff_format_type_get_type (void)
+{
+	static GType the_type = 0;
+	
+	if (the_type == 0)
+	{
+		static const GEnumValue values[] = {
+			{ GGIT_DIFF_FORMAT_PATCH,
+			  "GGIT_DIFF_FORMAT_PATCH",
+			  "patch" },
+			{ GGIT_DIFF_FORMAT_PATCH_HEADER,
+			  "GGIT_DIFF_FORMAT_PATCH_HEADER",
+			  "patch-header" },
+			{ GGIT_DIFF_FORMAT_RAW,
+			  "GGIT_DIFF_FORMAT_RAW",
+			  "raw" },
+			{ GGIT_DIFF_FORMAT_NAME_ONLY,
+			  "GGIT_DIFF_FORMAT_NAME_ONLY",
+			  "name-only" },
+			{ GGIT_DIFF_FORMAT_NAME_STATUS,
+			  "GGIT_DIFF_FORMAT_NAME_STATUS",
+			  "name-status" },
+			{ 0, NULL, NULL }
+		};
+		the_type = g_enum_register_static (
+				g_intern_static_string ("GgitDiffFormatType"),
+				values);
+	}
+	return the_type;
+}
+
 GType
 ggit_diff_option_get_type (void)
 {
@@ -162,9 +194,51 @@ ggit_diff_option_get_type (void)
 			{ GGIT_DIFF_REVERSE,
 			  "GGIT_DIFF_REVERSE",
 			  "reverse" },
+			{ GGIT_DIFF_INCLUDE_IGNORED,
+			  "GGIT_DIFF_INCLUDE_IGNORED",
+			  "include-ignored" },
+			{ GGIT_DIFF_RECURSE_IGNORED_DIRS,
+			  "GGIT_DIFF_RECURSE_IGNORED_DIRS",
+			  "recurse-ignored-dirs" },
+			{ GGIT_DIFF_INCLUDE_UNTRACKED,
+			  "GGIT_DIFF_INCLUDE_UNTRACKED",
+			  "include-untracked" },
+			{ GGIT_DIFF_RECURSE_UNTRACKED_DIRS,
+			  "GGIT_DIFF_RECURSE_UNTRACKED_DIRS",
+			  "recurse-untracked-dirs" },
+			{ GGIT_DIFF_INCLUDE_UNMODIFIED,
+			  "GGIT_DIFF_INCLUDE_UNMODIFIED",
+			  "include-unmodified" },
+			{ GGIT_DIFF_INCLUDE_TYPECHANGE,
+			  "GGIT_DIFF_INCLUDE_TYPECHANGE",
+			  "include-typechange" },
+			{ GGIT_DIFF_INCLUDE_TYPECHANGE_TREES,
+			  "GGIT_DIFF_INCLUDE_TYPECHANGE_TREES",
+			  "include-typechange-trees" },
+			{ GGIT_DIFF_IGNORE_FILE_MODE,
+			  "GGIT_DIFF_IGNORE_FILE_MODE",
+			  "ignore-file-mode" },
+			{ GGIT_DIFF_IGNORE_SUBMODULES,
+			  "GGIT_DIFF_IGNORE_SUBMODULES",
+			  "ignore-submodules" },
+			{ GGIT_DIFF_IGNORE_CASE,
+			  "GGIT_DIFF_IGNORE_CASE",
+			  "ignore-case" },
+			{ GGIT_DIFF_DISABLE_PATHSPEC_MATCH,
+			  "GGIT_DIFF_DISABLE_PATHSPEC_MATCH",
+			  "disable-pathspec-match" },
+			{ GGIT_DIFF_SKIP_BINARY_CHECK,
+			  "GGIT_DIFF_SKIP_BINARY_CHECK",
+			  "skip-binary-check" },
+			{ GGIT_DIFF_ENABLE_FAST_UNTRACKED_DIRS,
+			  "GGIT_DIFF_ENABLE_FAST_UNTRACKED_DIRS",
+			  "enable-fast-untracked-dirs" },
 			{ GGIT_DIFF_FORCE_TEXT,
 			  "GGIT_DIFF_FORCE_TEXT",
 			  "force-text" },
+			{ GGIT_DIFF_FORCE_BINARY,
+			  "GGIT_DIFF_FORCE_BINARY",
+			  "force-binary" },
 			{ GGIT_DIFF_IGNORE_WHITESPACE,
 			  "GGIT_DIFF_IGNORE_WHITESPACE",
 			  "ignore-whitespace" },
@@ -174,24 +248,18 @@ ggit_diff_option_get_type (void)
 			{ GGIT_DIFF_IGNORE_WHITESPACE_EOL,
 			  "GGIT_DIFF_IGNORE_WHITESPACE_EOL",
 			  "ignore-whitespace-eol" },
-			{ GGIT_DIFF_IGNORE_SUBMODULES,
-			  "GGIT_DIFF_IGNORE_SUBMODULES",
-			  "ignore-submodules" },
+			{ GGIT_DIFF_SHOW_UNTRACKED_CONTENT,
+			  "GGIT_DIFF_SHOW_UNTRACKED_CONTENT",
+			  "show-untracked-content" },
+			{ GGIT_DIFF_SHOW_UNMODIFIED,
+			  "GGIT_DIFF_SHOW_UNMODIFIED",
+			  "show-unmodified" },
 			{ GGIT_DIFF_PATIENCE,
 			  "GGIT_DIFF_PATIENCE",
 			  "patience" },
-			{ GGIT_DIFF_INCLUDE_IGNORED,
-			  "GGIT_DIFF_INCLUDE_IGNORED",
-			  "include-ignored" },
-			{ GGIT_DIFF_INCLUDE_UNTRACKED,
-			  "GGIT_DIFF_INCLUDE_UNTRACKED",
-			  "include-untracked" },
-			{ GGIT_DIFF_INCLUDE_UNMODIFIED,
-			  "GGIT_DIFF_INCLUDE_UNMODIFIED",
-			  "include-unmodified" },
-			{ GGIT_DIFF_RECURSE_UNTRACKED_DIRS,
-			  "GGIT_DIFF_RECURSE_UNTRACKED_DIRS",
-			  "recurse-untracked-dirs" },
+			{ GGIT_DIFF_MINIMAL,
+			  "GGIT_DIFF_MINIMAL",
+			  "minimal" },
 			{ 0, NULL, NULL }
 		};
 		the_type = g_flags_register_static (
@@ -419,6 +487,32 @@ ggit_remote_download_tags_type_get_type (void)
 	return the_type;
 }
 
+GType
+ggit_remote_completion_type_get_type (void)
+{
+	static GType the_type = 0;
+	
+	if (the_type == 0)
+	{
+		static const GEnumValue values[] = {
+			{ GGIT_REMOTE_COMPLETION_DOWNLOAD,
+			  "GGIT_REMOTE_COMPLETION_DOWNLOAD",
+			  "download" },
+			{ GGIT_REMOTE_COMPLETION_INDEXING,
+			  "GGIT_REMOTE_COMPLETION_INDEXING",
+			  "indexing" },
+			{ GGIT_REMOTE_COMPLETION_ERROR,
+			  "GGIT_REMOTE_COMPLETION_ERROR",
+			  "error" },
+			{ 0, NULL, NULL }
+		};
+		the_type = g_enum_register_static (
+				g_intern_static_string ("GgitRemoteCompletionType"),
+				values);
+	}
+	return the_type;
+}
+
 GType
 ggit_ref_type_get_type (void)
 {
@@ -590,9 +684,9 @@ ggit_submodule_ignore_get_type (void)
 	if (the_type == 0)
 	{
 		static const GEnumValue values[] = {
-			{ GGIT_SUBMODULE_IGNORE_DEFAULT,
-			  "GGIT_SUBMODULE_IGNORE_DEFAULT",
-			  "default" },
+			{ GGIT_SUBMODULE_IGNORE_RESET,
+			  "GGIT_SUBMODULE_IGNORE_RESET",
+			  "reset" },
 			{ GGIT_SUBMODULE_IGNORE_NONE,
 			  "GGIT_SUBMODULE_IGNORE_NONE",
 			  "none" },
@@ -681,6 +775,9 @@ ggit_submodule_update_get_type (void)
 	if (the_type == 0)
 	{
 		static const GEnumValue values[] = {
+			{ GGIT_SUBMODULE_UPDATE_RESET,
+			  "GGIT_SUBMODULE_UPDATE_RESET",
+			  "reset" },
 			{ GGIT_SUBMODULE_UPDATE_CHECKOUT,
 			  "GGIT_SUBMODULE_UPDATE_CHECKOUT",
 			  "checkout" },
@@ -690,6 +787,9 @@ ggit_submodule_update_get_type (void)
 			{ GGIT_SUBMODULE_UPDATE_MERGE,
 			  "GGIT_SUBMODULE_UPDATE_MERGE",
 			  "merge" },
+			{ GGIT_SUBMODULE_UPDATE_NONE,
+			  "GGIT_SUBMODULE_UPDATE_NONE",
+			  "none" },
 			{ 0, NULL, NULL }
 		};
 		the_type = g_enum_register_static (
@@ -795,9 +895,6 @@ ggit_status_show_get_type (void)
 			{ GGIT_STATUS_SHOW_WORKDIR_ONLY,
 			  "GGIT_STATUS_SHOW_WORKDIR_ONLY",
 			  "workdir-only" },
-			{ GGIT_STATUS_SHOW_INDEX_THEN_WORKDIR,
-			  "GGIT_STATUS_SHOW_INDEX_THEN_WORKDIR",
-			  "index-then-workdir" },
 			{ 0, NULL, NULL }
 		};
 		the_type = g_enum_register_static (
