@@ -25,6 +25,9 @@ GType ggit_create_flags_get_type	(void) G_GNUC_CONST;
 #define GGIT_TYPE_DELTA_TYPE	(ggit_delta_type_get_type())
 GType ggit_delta_type_get_type	(void) G_GNUC_CONST;
 
+#define GGIT_TYPE_DIFF_FORMAT_TYPE	(ggit_diff_format_type_get_type())
+GType ggit_diff_format_type_get_type	(void) G_GNUC_CONST;
+
 #define GGIT_TYPE_DIFF_OPTION	(ggit_diff_option_get_type())
 GType ggit_diff_option_get_type	(void) G_GNUC_CONST;
 
@@ -49,6 +52,9 @@ GType ggit_merge_tree_flags_get_type	(void) G_GNUC_CONST;
 #define GGIT_TYPE_REMOTE_DOWNLOAD_TAGS_TYPE	(ggit_remote_download_tags_type_get_type())
 GType ggit_remote_download_tags_type_get_type	(void) G_GNUC_CONST;
 
+#define GGIT_TYPE_REMOTE_COMPLETION_TYPE	(ggit_remote_completion_type_get_type())
+GType ggit_remote_completion_type_get_type	(void) G_GNUC_CONST;
+
 #define GGIT_TYPE_REF_TYPE	(ggit_ref_type_get_type())
 GType ggit_ref_type_get_type	(void) G_GNUC_CONST;
 
