@@ -20,6 +20,7 @@
 
 #include <gio/gio.h>
 #include <git2.h>
+#include <git2/sys/commit.h>
 
 #include "ggit-error.h"
 #include "ggit-oid.h"
@@ -32,6 +33,7 @@
 #include "ggit-clone-options.h"
 #include "ggit-status-options.h"
 #include "ggit-tree-builder.h"
+#include "ggit-branch-enumerator.h"
 
 #define GGIT_REPOSITORY_GET_PRIVATE(object)(G_TYPE_INSTANCE_GET_PRIVATE((object), GGIT_TYPE_REPOSITORY, GgitRepositoryPrivate))
 
@@ -363,7 +365,7 @@ ggit_repository_initable_init (GInitable    *initable,
 	                  repo,
 	                  (GDestroyNotify)git_repository_free);
 
-	if (!priv->workdir && !priv->is_bare)
+	if (success && !priv->workdir && !priv->is_bare)
 	{
 		priv->workdir = ggit_repository_get_workdir (GGIT_REPOSITORY (initable));
 	}
@@ -722,7 +724,10 @@ ggit_repository_create_symbolic_reference (GgitRepository  *repository,
  * @repository: a #GgitRepository.
  * @error: a #GError for error reporting, or %NULL.
  *
- * Get the current HEAD reference of the repository.
+ * Get and resolves the current HEAD reference of the repository. Note that the
+ * returned ref is already resolved (if HEAD is symbolic). If you want to
+ * retrieve the symbolic ref called HEAD, then use #ggit_repository_lookup_reference
+ * instead.
  *
  * Returns: (transfer full): a #GgitRef
  *
@@ -831,7 +836,7 @@ ggit_repository_is_head_detached (GgitRepository  *repository,
 }
 
 /**
- * ggit_repository_is_head_orphan:
+ * ggit_repository_is_head_unborn:
  * @repository: a #GgitRepository.
  * @error: a #GError for error reporting, or %NULL.
  *
@@ -843,7 +848,7 @@ ggit_repository_is_head_detached (GgitRepository  *repository,
  * Returns: %TRUE if the current branch is an orphan.
  */
 gboolean
-ggit_repository_is_head_orphan (GgitRepository  *repository,
+ggit_repository_is_head_unborn (GgitRepository  *repository,
                                 GError         **error)
 {
 	gint ret;
@@ -851,7 +856,7 @@ ggit_repository_is_head_orphan (GgitRepository  *repository,
 	g_return_val_if_fail (GGIT_IS_REPOSITORY (repository), FALSE);
 	g_return_val_if_fail (error == NULL || *error == NULL, FALSE);
 
-	ret = git_repository_head_orphan (_ggit_native_get (repository));
+	ret = git_repository_head_unborn (_ggit_native_get (repository));
 
 	if (ret < 0)
 	{
@@ -1389,42 +1394,39 @@ ggit_repository_create_branch (GgitRepository   *repository,
 	return _ggit_branch_wrap (reference);
 }
 
-typedef gint (* _GitBranchesCallback) (const gchar  *branch_name,
-                                       git_branch_t  branch_type,
-                                       gpointer      payload);
-
 /**
  * ggit_repository_branches_foreach:
  * @repository: a #GgitRepository.
- * @branch_type: a GgitBranchType.
- * @callback: (scope call): a #GgitBranchesCallback.
- * @user_data: callback user data.
+ * @list_type: a GgitBranchType.
  * @error: a #GError for error reporting, or %NULL.
  *
- * Foreach branch of type @branch_type the callback @callback is called.
+ * Get a branch enumerator to enumerate over all branches of the specified
+ * @list_type in @repository.
+ *
+ * Returns: (transfer full): a branch enumerator.
  **/
-void
-ggit_repository_branches_foreach (GgitRepository        *repository,
-                                  GgitBranchType         branch_type,
-                                  GgitBranchesCallback   callback,
-                                  gpointer               user_data,
-                                  GError               **error)
+GgitBranchEnumerator *
+ggit_repository_enumerate_branches (GgitRepository  *repository,
+                                    GgitBranchType   list_type,
+                                    GError         **error)
 {
+	git_branch_iterator *iter;
 	gint ret;
 
-	g_return_if_fail (GGIT_IS_REPOSITORY (repository));
-	g_return_if_fail (callback != NULL);
-	g_return_if_fail (error == NULL || *error == NULL);
+	g_return_val_if_fail (GGIT_IS_REPOSITORY (repository), NULL);
+	g_return_val_if_fail (error == NULL || *error == NULL, NULL);
 
-	ret = git_branch_foreach (_ggit_native_get (repository),
-	                          branch_type,
-	                          (_GitBranchesCallback) callback,
-	                          user_data);
+	ret = git_branch_iterator_new (&iter,
+	                               _ggit_native_get (repository),
+	                               (git_branch_t)list_type);
 
 	if (ret != GIT_OK)
 	{
 		_ggit_error_set (error, ret);
+		return NULL;
 	}
+
+	return _ggit_branch_enumerator_wrap (iter);
 }
 
 /**
@@ -1454,7 +1456,7 @@ ggit_repository_lookup_branch (GgitRepository *repository,
 	ret = git_branch_lookup (&branch,
 	                         _ggit_native_get (repository),
 	                         branch_name,
-	                         branch_type);
+	                         (git_branch_t)branch_type);
 
 	if (ret != GIT_OK)
 	{
@@ -1707,7 +1709,7 @@ ggit_repository_reset (GgitRepository  *repository,
 
 	ret = git_reset (_ggit_native_get (repository),
 	                 _ggit_native_get (target),
-	                 reset_type);
+	                 (git_reset_t)reset_type);
 
 	if (ret != GIT_OK)
 	{
@@ -2102,6 +2104,76 @@ ggit_repository_create_commit (GgitRepository  *repository,
 	return _ggit_oid_wrap (&oid);
 }
 
+/**
+ * ggit_repository_create_commit_from_oids:
+ * @repository: a #GgitRepository.
+ * @update_ref: (allow-none): name of the reference to update.
+ * @author: author signature.
+ * @committer: committer signature (and time of commit).
+ * @message_encoding: (allow-none): message encoding.
+ * @message: commit message.
+ * @tree: the tree of objects to commit.
+ * @parents: (array length=parent_count): parent commits.
+ * @parent_count: number of parent commits in @parents.
+ * @error: a #GError for error reporting, or %NULL.
+ *
+ * Create a new commit. If @update_ref is not %NULL, the given reference will
+ * be updated to point to the newly created commit. Use "HEAD" to update the
+ * HEAD of the current branch and make it point to this commit.
+ *
+ * If @message_encoding is set to %NULL, "UTF-8" encoding is assumed for the
+ * provided @message. Note that @message will not be cleaned up automatically.
+ * You can use #ggit_message_prettify to do this yourself if needed.
+ *
+ * Returns: the #GgitOId of the created commit object, or %NULL in case of an error.
+ *
+ */
+GgitOId *
+ggit_repository_create_commit_from_oids (GgitRepository  *repository,
+                                         const gchar     *update_ref,
+                                         GgitSignature   *author,
+                                         GgitSignature   *committer,
+                                         const gchar     *message_encoding,
+                                         const gchar     *message,
+                                         GgitOId         *tree,
+                                         GgitOId        **parents,
+                                         gint             parent_count,
+                                         GError         **error)
+{
+	gint ret;
+	git_oid oid;
+	git_oid **parents_native;
+	gint i;
+
+	parents_native = g_new0 (git_oid *, parent_count);
+
+	for (i = 0; i < parent_count; ++i)
+	{
+		parents_native[i] = (git_oid *)_ggit_oid_get_oid (parents[i]);
+	}
+
+	ret = git_commit_create_from_oids (&oid,
+	                                   _ggit_native_get (repository),
+	                                   update_ref,
+	                                   _ggit_native_get (author),
+	                                   _ggit_native_get (committer),
+	                                   message_encoding,
+	                                   message,
+	                                   _ggit_oid_get_oid (tree),
+	                                   parent_count,
+	                                   (git_oid const **)parents_native);
+
+	g_free (parents_native);
+
+	if (ret != GIT_OK)
+	{
+		_ggit_error_set (error, ret);
+		return NULL;
+	}
+
+	return _ggit_oid_wrap (&oid);
+}
+
 /**
  * ggit_repository_create_tree_builder:
  * @repository: a #GgitRepository.
