@@ -136,6 +136,18 @@ GgitOId            *ggit_repository_create_commit     (GgitRepository        *re
                                                        gint                   parent_count,
                                                        GError               **error);
 
+GgitOId            *ggit_repository_create_commit_from_oids (
+                                                       GgitRepository        *repository,
+                                                       const gchar           *update_ref,
+                                                       GgitSignature         *author,
+                                                       GgitSignature         *committer,
+                                                       const gchar           *message_encoding,
+                                                       const gchar           *message,
+                                                       GgitOId               *tree,
+                                                       GgitOId              **parents,
+                                                       gint                   parent_count,
+                                                       GError               **error);
+
 GgitOId            *ggit_repository_create_tag        (GgitRepository        *repository,
                                                        const gchar           *tag_name,
                                                        GgitObject            *target,
@@ -186,11 +198,9 @@ GgitBranch         *ggit_repository_create_branch     (GgitRepository        *re
                                                        GgitCreateFlags        flags,
                                                        GError               **error);
 
-void                ggit_repository_branches_foreach  (GgitRepository        *repository,
-                                                       GgitBranchType         branch_type,
-                                                       GgitBranchesCallback   callback,
-                                                       gpointer               user_data,
-                                                       GError               **error);
+GgitBranchEnumerator *ggit_repository_enumerate_branches (GgitRepository        *repository,
+                                                          GgitBranchType         list_flags,
+                                                          GError               **error);
 
 GgitBranch         *ggit_repository_lookup_branch     (GgitRepository        *repository,
                                                        const gchar           *branch_name,
@@ -218,7 +228,7 @@ GFile              *ggit_repository_discover          (GFile                 *lo
 gboolean            ggit_repository_is_head_detached  (GgitRepository        *repository,
                                                        GError               **error);
 
-gboolean            ggit_repository_is_head_orphan    (GgitRepository        *repository,
+gboolean            ggit_repository_is_head_unborn    (GgitRepository        *repository,
                                                        GError               **error);
 
 gboolean            ggit_repository_is_empty          (GgitRepository        *repository,
