@@ -48,20 +48,37 @@ ASSERT_ENUM (GGIT_DELTA_COPIED,     GIT_DELTA_COPIED);
 ASSERT_ENUM (GGIT_DELTA_IGNORED,    GIT_DELTA_IGNORED);
 ASSERT_ENUM (GGIT_DELTA_UNTRACKED,  GIT_DELTA_UNTRACKED);
 
+ASSERT_ENUM (GGIT_DIFF_FORMAT_PATCH,         GIT_DIFF_FORMAT_PATCH);
+ASSERT_ENUM (GGIT_DIFF_FORMAT_PATCH_HEADER,  GIT_DIFF_FORMAT_PATCH_HEADER);
+ASSERT_ENUM (GGIT_DIFF_FORMAT_RAW,           GIT_DIFF_FORMAT_RAW);
+ASSERT_ENUM (GGIT_DIFF_FORMAT_NAME_ONLY,     GIT_DIFF_FORMAT_NAME_ONLY);
+ASSERT_ENUM (GGIT_DIFF_FORMAT_NAME_STATUS,   GIT_DIFF_FORMAT_NAME_STATUS);
 
-ASSERT_ENUM (GGIT_DIFF_NORMAL,                   GIT_DIFF_NORMAL);
-ASSERT_ENUM (GGIT_DIFF_REVERSE,                  GIT_DIFF_REVERSE);
-ASSERT_ENUM (GGIT_DIFF_FORCE_TEXT,               GIT_DIFF_FORCE_TEXT);
-ASSERT_ENUM (GGIT_DIFF_IGNORE_WHITESPACE,        GIT_DIFF_IGNORE_WHITESPACE);
-ASSERT_ENUM (GGIT_DIFF_IGNORE_WHITESPACE_CHANGE, GIT_DIFF_IGNORE_WHITESPACE_CHANGE);
-ASSERT_ENUM (GGIT_DIFF_IGNORE_WHITESPACE_EOL,    GIT_DIFF_IGNORE_WHITESPACE_EOL);
-ASSERT_ENUM (GGIT_DIFF_IGNORE_SUBMODULES,        GIT_DIFF_IGNORE_SUBMODULES);
-ASSERT_ENUM (GGIT_DIFF_PATIENCE,                 GIT_DIFF_PATIENCE);
-ASSERT_ENUM (GGIT_DIFF_INCLUDE_IGNORED,          GIT_DIFF_INCLUDE_IGNORED);
-ASSERT_ENUM (GGIT_DIFF_INCLUDE_UNTRACKED,        GIT_DIFF_INCLUDE_UNTRACKED);
-ASSERT_ENUM (GGIT_DIFF_INCLUDE_UNMODIFIED,       GIT_DIFF_INCLUDE_UNMODIFIED);
-ASSERT_ENUM (GGIT_DIFF_RECURSE_UNTRACKED_DIRS,   GIT_DIFF_RECURSE_UNTRACKED_DIRS);
 
+ASSERT_ENUM (GGIT_DIFF_NORMAL,                     GIT_DIFF_NORMAL);
+ASSERT_ENUM (GGIT_DIFF_REVERSE,                    GIT_DIFF_REVERSE);
+ASSERT_ENUM (GGIT_DIFF_INCLUDE_IGNORED,            GIT_DIFF_INCLUDE_IGNORED);
+ASSERT_ENUM (GGIT_DIFF_RECURSE_IGNORED_DIRS,       GIT_DIFF_RECURSE_IGNORED_DIRS);
+ASSERT_ENUM (GGIT_DIFF_INCLUDE_UNTRACKED,          GIT_DIFF_INCLUDE_UNTRACKED);
+ASSERT_ENUM (GGIT_DIFF_RECURSE_UNTRACKED_DIRS,     GIT_DIFF_RECURSE_UNTRACKED_DIRS);
+ASSERT_ENUM (GGIT_DIFF_INCLUDE_UNMODIFIED,         GIT_DIFF_INCLUDE_UNMODIFIED);
+ASSERT_ENUM (GGIT_DIFF_INCLUDE_TYPECHANGE,         GIT_DIFF_INCLUDE_TYPECHANGE);
+ASSERT_ENUM (GGIT_DIFF_INCLUDE_TYPECHANGE_TREES,   GIT_DIFF_INCLUDE_TYPECHANGE_TREES);
+ASSERT_ENUM (GGIT_DIFF_IGNORE_FILE_MODE,           GIT_DIFF_IGNORE_FILEMODE);
+ASSERT_ENUM (GGIT_DIFF_IGNORE_SUBMODULES,          GIT_DIFF_IGNORE_SUBMODULES);
+ASSERT_ENUM (GGIT_DIFF_IGNORE_CASE,                GIT_DIFF_IGNORE_CASE);
+ASSERT_ENUM (GGIT_DIFF_DISABLE_PATHSPEC_MATCH,     GIT_DIFF_DISABLE_PATHSPEC_MATCH);
+ASSERT_ENUM (GGIT_DIFF_SKIP_BINARY_CHECK,          GIT_DIFF_SKIP_BINARY_CHECK);
+ASSERT_ENUM (GGIT_DIFF_ENABLE_FAST_UNTRACKED_DIRS, GIT_DIFF_ENABLE_FAST_UNTRACKED_DIRS);
+ASSERT_ENUM (GGIT_DIFF_FORCE_TEXT,                 GIT_DIFF_FORCE_TEXT);
+ASSERT_ENUM (GGIT_DIFF_FORCE_BINARY,               GIT_DIFF_FORCE_BINARY);
+ASSERT_ENUM (GGIT_DIFF_IGNORE_WHITESPACE,          GIT_DIFF_IGNORE_WHITESPACE);
+ASSERT_ENUM (GGIT_DIFF_IGNORE_WHITESPACE_CHANGE,   GIT_DIFF_IGNORE_WHITESPACE_CHANGE);
+ASSERT_ENUM (GGIT_DIFF_IGNORE_WHITESPACE_EOL,      GIT_DIFF_IGNORE_WHITESPACE_EOL);
+ASSERT_ENUM (GGIT_DIFF_SHOW_UNTRACKED_CONTENT,     GIT_DIFF_SHOW_UNTRACKED_CONTENT);
+ASSERT_ENUM (GGIT_DIFF_SHOW_UNMODIFIED,            GIT_DIFF_SHOW_UNMODIFIED);
+ASSERT_ENUM (GGIT_DIFF_PATIENCE,                   GIT_DIFF_PATIENCE);
+ASSERT_ENUM (GGIT_DIFF_MINIMAL,                    GIT_DIFF_MINIMAL);
 
 ASSERT_ENUM (GGIT_DIFF_FLAG_VALID_OID,  GIT_DIFF_FLAG_VALID_OID);
 ASSERT_ENUM (GGIT_DIFF_FLAG_BINARY,     GIT_DIFF_FLAG_BINARY);
@@ -105,6 +122,10 @@ ASSERT_ENUM (GGIT_REMOTE_DOWNLOAD_TAGS_AUTO,  GIT_REMOTE_DOWNLOAD_TAGS_AUTO);
 ASSERT_ENUM (GGIT_REMOTE_DOWNLOAD_TAGS_NONE,  GIT_REMOTE_DOWNLOAD_TAGS_NONE);
 ASSERT_ENUM (GGIT_REMOTE_DOWNLOAD_TAGS_ALL,   GIT_REMOTE_DOWNLOAD_TAGS_ALL);
 
+ASSERT_ENUM (GGIT_REMOTE_COMPLETION_DOWNLOAD, GIT_REMOTE_COMPLETION_DOWNLOAD);
+ASSERT_ENUM (GGIT_REMOTE_COMPLETION_INDEXING, GIT_REMOTE_COMPLETION_INDEXING);
+ASSERT_ENUM (GGIT_REMOTE_COMPLETION_ERROR,    GIT_REMOTE_COMPLETION_ERROR);
+
 ASSERT_ENUM (GGIT_REF_INVALID,  GIT_REF_INVALID);
 ASSERT_ENUM (GGIT_REF_OID,      GIT_REF_OID);
 ASSERT_ENUM (GGIT_REF_SYMBOLIC, GIT_REF_SYMBOLIC);
@@ -139,11 +160,11 @@ ASSERT_ENUM (GGIT_STATUS_WORKING_TREE_TYPECHANGE, GIT_STATUS_WT_TYPECHANGE);
 ASSERT_ENUM (GGIT_STATUS_IGNORED,                 GIT_STATUS_IGNORED);
 
 
-ASSERT_ENUM (GGIT_SUBMODULE_IGNORE_DEFAULT, GIT_SUBMODULE_IGNORE_DEFAULT);
-ASSERT_ENUM (GGIT_SUBMODULE_IGNORE_NONE, GIT_SUBMODULE_IGNORE_NONE);
+ASSERT_ENUM (GGIT_SUBMODULE_IGNORE_RESET,     GIT_SUBMODULE_IGNORE_RESET);
+ASSERT_ENUM (GGIT_SUBMODULE_IGNORE_NONE,      GIT_SUBMODULE_IGNORE_NONE);
 ASSERT_ENUM (GGIT_SUBMODULE_IGNORE_UNTRACKED, GIT_SUBMODULE_IGNORE_UNTRACKED);
-ASSERT_ENUM (GGIT_SUBMODULE_IGNORE_DIRTY, GIT_SUBMODULE_IGNORE_DIRTY);
-ASSERT_ENUM (GGIT_SUBMODULE_IGNORE_ALL, GIT_SUBMODULE_IGNORE_ALL);
+ASSERT_ENUM (GGIT_SUBMODULE_IGNORE_DIRTY,     GIT_SUBMODULE_IGNORE_DIRTY);
+ASSERT_ENUM (GGIT_SUBMODULE_IGNORE_ALL,       GIT_SUBMODULE_IGNORE_ALL);
 
 
 ASSERT_ENUM (GGIT_SUBMODULE_STATUS_IN_HEAD, GIT_SUBMODULE_STATUS_IN_HEAD);
@@ -162,9 +183,11 @@ ASSERT_ENUM (GGIT_SUBMODULE_STATUS_WD_WD_MODIFIED, GIT_SUBMODULE_STATUS_WD_WD_MO
 ASSERT_ENUM (GGIT_SUBMODULE_STATUS_WD_UNTRACKED, GIT_SUBMODULE_STATUS_WD_UNTRACKED);
 
 
+ASSERT_ENUM (GGIT_SUBMODULE_UPDATE_RESET,    GIT_SUBMODULE_UPDATE_RESET);
 ASSERT_ENUM (GGIT_SUBMODULE_UPDATE_CHECKOUT, GIT_SUBMODULE_UPDATE_CHECKOUT);
 ASSERT_ENUM (GGIT_SUBMODULE_UPDATE_REBASE,   GIT_SUBMODULE_UPDATE_REBASE);
 ASSERT_ENUM (GGIT_SUBMODULE_UPDATE_MERGE,    GIT_SUBMODULE_UPDATE_MERGE);
+ASSERT_ENUM (GGIT_SUBMODULE_UPDATE_NONE,     GIT_SUBMODULE_UPDATE_NONE);
 
 ASSERT_ENUM (GGIT_STATUS_OPTION_INCLUDE_UNTRACKED, GIT_STATUS_OPT_INCLUDE_UNTRACKED);
 ASSERT_ENUM (GGIT_STATUS_OPTION_INCLUDE_IGNORED, GIT_STATUS_OPT_INCLUDE_IGNORED);
@@ -180,8 +203,7 @@ ASSERT_ENUM (GGIT_STATUS_OPTION_SORT_CASE_SENSITIVELY, GIT_STATUS_OPT_SORT_CASE_
 ASSERT_ENUM (GGIT_STATUS_OPTION_DEFAULT, GIT_STATUS_OPT_DEFAULTS);
 
 ASSERT_ENUM (GGIT_STATUS_SHOW_INDEX_AND_WORKDIR, GIT_STATUS_SHOW_INDEX_AND_WORKDIR);
-ASSERT_ENUM (GGIT_STATUS_SHOW_INDEX_ONLY, GIT_STATUS_SHOW_INDEX_ONLY);
-ASSERT_ENUM (GGIT_STATUS_SHOW_WORKDIR_ONLY, GIT_STATUS_SHOW_WORKDIR_ONLY);
-ASSERT_ENUM (GGIT_STATUS_SHOW_INDEX_THEN_WORKDIR, GIT_STATUS_SHOW_INDEX_THEN_WORKDIR);
+ASSERT_ENUM (GGIT_STATUS_SHOW_INDEX_ONLY,        GIT_STATUS_SHOW_INDEX_ONLY);
+ASSERT_ENUM (GGIT_STATUS_SHOW_WORKDIR_ONLY,      GIT_STATUS_SHOW_WORKDIR_ONLY);
 
 /* ex:set ts=8 noet: */
