@@ -46,6 +46,13 @@ typedef struct _GgitBlobOutputStream GgitBlobOutputStream;
  */
 typedef struct _GgitBranch GgitBranch;
 
+/**
+ * GgitBranchEnumerator:
+ *
+ * Represents a branch enumerator.
+ */
+typedef struct _GgitBranchEnumerator GgitBranchEnumerator;
+
 /**
  * GgitCloneOptions:
  *
@@ -96,11 +103,11 @@ typedef struct _GgitCred GgitCred;
 typedef struct _GgitCredPlaintext GgitCredPlaintext;
 
 /**
- * GgitDiffList:
+ * GgitDiff:
  *
  * Represents a diff list.
  */
-typedef struct _GgitDiffList GgitDiffList;
+typedef struct _GgitDiff GgitDiff;
 
 /**
  * GgitDiffDelta:
@@ -109,13 +116,6 @@ typedef struct _GgitDiffList GgitDiffList;
  */
 typedef struct _GgitDiffDelta GgitDiffDelta;
 
-/**
- * GgitDiffPatch:
- *
- * Represents a patch object.
- */
-typedef struct _GgitDiffPatch GgitDiffPatch;
-
 /**
  * GgitDiffFile:
  *
@@ -123,6 +123,20 @@ typedef struct _GgitDiffPatch GgitDiffPatch;
  */
 typedef struct _GgitDiffFile GgitDiffFile;
 
+/**
+ * GgitDiffHunk:
+ *
+ * Represents the hunk of a diff.
+ */
+typedef struct _GgitDiffHunk GgitDiffHunk;
+
+/**
+ * GgitDiffLine:
+ *
+ * Represents the line of a diff.
+ */
+typedef struct _GgitDiffLine GgitDiffLine;
+
 /**
  * GgitDiffOptions:
  *
@@ -131,11 +145,11 @@ typedef struct _GgitDiffFile GgitDiffFile;
 typedef struct _GgitDiffOptions GgitDiffOptions;
 
 /**
- * GgitDiffRange:
+ * GgitDiffSimilarityMetric:
  *
- * Represents the hunk of a diff.
+ * Represents a similarity metric.
  */
-typedef struct _GgitDiffRange GgitDiffRange;
+typedef struct _GgitDiffSimilarityMetric GgitDiffSimilarityMetric;
 
 /**
  * GgitIndex:
@@ -214,6 +228,13 @@ typedef struct _GgitObjectFactoryBase GgitObjectFactoryBase;
  */
 typedef struct _GgitOId GgitOId;
 
+/**
+ * GgitPatch:
+ *
+ * Represents a patch object.
+ */
+typedef struct _GgitPatch GgitPatch;
+
 /**
  * GgitPush:
  *
@@ -256,6 +277,20 @@ typedef struct _GgitReflogEntry GgitReflogEntry;
  */
 typedef struct _GgitRemote GgitRemote;
 
+/**
+ * GgitRemoteHead:
+ *
+ * Represents a git remote head.
+ */
+typedef struct _GgitRemoteHead GgitRemoteHead;
+
+/**
+ * GgitRemoteCallbacks:
+ *
+ * Represents a git remote callbacks.
+ */
+typedef struct _GgitRemoteCallbacks GgitRemoteCallbacks;
+
 /**
  * GgitRepository:
  *
@@ -404,36 +439,84 @@ typedef enum {
 	GGIT_DELTA_UNTRACKED  = 7
 } GgitDeltaType;
 
+/**
+ * GgitDiffFormatType:
+ * @GGIT_DIFF_FORMAT_PATCH: full git diff.
+ * @GGIT_DIFF_FORMAT_PATCH_HEADER: just the file headers of patch.
+ * @GGIT_DIFF_FORMAT_RAW: like git diff --raw.
+ * @GGIT_DIFF_FORMAT_NAME_ONLY: like git diff --name-only.
+ * @GGIT_DIFF_FORMAT_NAME_STATUS: like git diff --name-status.
+ *
+ * Possible output formats for diff data.
+ */
+typedef enum {
+	GGIT_DIFF_FORMAT_PATCH        = 1u,
+	GGIT_DIFF_FORMAT_PATCH_HEADER = 2u,
+	GGIT_DIFF_FORMAT_RAW          = 3u,
+	GGIT_DIFF_FORMAT_NAME_ONLY    = 4u,
+	GGIT_DIFF_FORMAT_NAME_STATUS  = 5u
+} GgitDiffFormatType;
+
 /**
  * GgitDiffOption:
  * @GGIT_DIFF_NORMAL: normal.
- * @GGIT_DIFF_REVERSE: reverse.
+ * @GGIT_DIFF_REVERSE: reverse the sides of the diff.
+ * @GGIT_DIFF_INCLUDE_IGNORED: include ignored files.
+ * @GGIT_DIFF_RECURSE_IGNORED_DIRS: also add all files under ignored dirs.
+ * @GGIT_DIFF_INCLUDE_UNTRACKED: include untracked files.
+ * @GGIT_DIFF_RECURSE_UNTRACKED_DIRS: recurse to untracked directories.
+ * @GGIT_DIFF_INCLUDE_UNMODIFIED: include unmodified files.
+ * @GGIT_DIFF_INCLUDE_TYPECHANGE: enable generation of typechange detal records.
+ * @GGIT_DIFF_INCLUDE_TYPECHANGE_TREES: try to label tree transitions as type changes.
+ * @GGIT_DIFF_IGNORE_FILE_MODE: ignore file mode changes.
+ * @GGIT_DIFF_IGNORE_SUBMODULES: ignore submodules.
+ * @GGIT_DIFF_IGNORE_CASE: use case insensitive filename comparison.
+ * @GGIT_DIFF_DISABLE_PATHSPEC_MATCH: use exact path matching.
+ * @GGIT_DIFF_SKIP_BINARY_CHECK: disable updating the binary flag in delta records.
+ * @GGIT_DIFF_ENABLE_FAST_UNTRACKED_DIRS: immediately label untracked directories as
+ * untracked, without checking inside.
  * @GGIT_DIFF_FORCE_TEXT: force text.
+ * @GGIT_DIFF_FORCE_BINARY: treat all files as binary, disabling text diffs.
  * @GGIT_DIFF_IGNORE_WHITESPACE: ignore whitespace.
  * @GGIT_DIFF_IGNORE_WHITESPACE_CHANGE: ignore whitespace change.
  * @GGIT_DIFF_IGNORE_WHITESPACE_EOL: ignore whitespace at end-of-line.
- * @GGIT_DIFF_IGNORE_SUBMODULES: ignore submodules.
+ * @GGIT_DIFF_SHOW_UNTRACKED_CONTENT: include content of untracked files.
+ * this implies GGIT_DIFF_INCLUDE_UNTRACKED but not GGIT_DIFF_RECURSE_UNTRACKED_DIRS.
+ * @GGIT_DIFF_SHOW_UNMODIFIED: show unmodified files.
  * @GGIT_DIFF_PATIENCE: generate using the "patience diff" algorithm.
- * @GGIT_DIFF_INCLUDE_IGNORED: include ignored files.
- * @GGIT_DIFF_INCLUDE_UNTRACKED: include untracked files.
- * @GGIT_DIFF_INCLUDE_UNMODIFIED: include unmodified files.
- * @GGIT_DIFF_RECURSE_UNTRACKED_DIRS: recurse to untracked directories.
+ * @GGIT_DIFF_MINIMAL: take extra time to find minimal diff.
  *
  * How the diff should be generated.
  */
 typedef enum {
-	GGIT_DIFF_NORMAL                   = 0,
-	GGIT_DIFF_REVERSE                  = 1 << 0,
-	GGIT_DIFF_FORCE_TEXT               = 1 << 1,
-	GGIT_DIFF_IGNORE_WHITESPACE        = 1 << 2,
-	GGIT_DIFF_IGNORE_WHITESPACE_CHANGE = 1 << 3,
-	GGIT_DIFF_IGNORE_WHITESPACE_EOL    = 1 << 4,
-	GGIT_DIFF_IGNORE_SUBMODULES        = 1 << 5,
-	GGIT_DIFF_PATIENCE                 = 1 << 6,
-	GGIT_DIFF_INCLUDE_IGNORED          = 1 << 7,
-	GGIT_DIFF_INCLUDE_UNTRACKED        = 1 << 8,
-	GGIT_DIFF_INCLUDE_UNMODIFIED       = 1 << 9,
-	GGIT_DIFF_RECURSE_UNTRACKED_DIRS   = 1 << 10
+	GGIT_DIFF_NORMAL                     = 0,
+	GGIT_DIFF_REVERSE                    = 1u << 0,
+	GGIT_DIFF_INCLUDE_IGNORED            = 1u << 1,
+	GGIT_DIFF_RECURSE_IGNORED_DIRS       = 1u << 2,
+	GGIT_DIFF_INCLUDE_UNTRACKED          = 1u << 3,
+	GGIT_DIFF_RECURSE_UNTRACKED_DIRS     = 1u << 4,
+	GGIT_DIFF_INCLUDE_UNMODIFIED         = 1u << 5,
+	GGIT_DIFF_INCLUDE_TYPECHANGE         = 1u << 6,
+	GGIT_DIFF_INCLUDE_TYPECHANGE_TREES   = 1u << 7,
+	GGIT_DIFF_IGNORE_FILE_MODE           = 1u << 8,
+	GGIT_DIFF_IGNORE_SUBMODULES          = 1u << 9,
+	GGIT_DIFF_IGNORE_CASE                = 1u << 10,
+
+	GGIT_DIFF_DISABLE_PATHSPEC_MATCH     = 1u << 12,
+	GGIT_DIFF_SKIP_BINARY_CHECK          = 1u << 13,
+	GGIT_DIFF_ENABLE_FAST_UNTRACKED_DIRS = 1u << 14,
+
+	GGIT_DIFF_FORCE_TEXT                 = 1u << 20,
+	GGIT_DIFF_FORCE_BINARY               = 1u << 21,
+	GGIT_DIFF_IGNORE_WHITESPACE          = 1u << 22,
+	GGIT_DIFF_IGNORE_WHITESPACE_CHANGE   = 1u << 23,
+	GGIT_DIFF_IGNORE_WHITESPACE_EOL      = 1u << 24,
+
+	GGIT_DIFF_SHOW_UNTRACKED_CONTENT     = 1u << 25,
+	GGIT_DIFF_SHOW_UNMODIFIED            = 1u << 26,
+
+	GGIT_DIFF_PATIENCE                   = 1u << 28,
+	GGIT_DIFF_MINIMAL                    = 1u << 29
 } GgitDiffOption;
 
 /**
@@ -549,6 +632,21 @@ typedef enum {
 	GGIT_REMOTE_DOWNLOAD_TAGS_ALL  = 2
 } GgitRemoteDownloadTagsType;
 
+/* NOTE: keep in sync with git2/remote.h */
+/**
+ * GgitRemoteCompletionType:
+ * @GGIT_REMOTE_COMPLETION_DOWNLOAD: download.
+ * @GGIT_REMOTE_COMPLETION_INDEXING: indexing.
+ * @GGIT_REMOTE_COMPLETION_ERROR: error.
+ *
+ * Argument to the completion callback which tells it which operation finished.
+ */
+typedef enum {
+	GGIT_REMOTE_COMPLETION_DOWNLOAD = 0,
+	GGIT_REMOTE_COMPLETION_INDEXING = 1,
+	GGIT_REMOTE_COMPLETION_ERROR = 2
+} GgitRemoteCompletionType;
+
 /* NOTE: keep in sync with git2/refs.h */
 /**
  * GgitRefType:
@@ -654,20 +752,21 @@ typedef enum {
 
 /**
  * GgitSubmoduleIgnore:
- * @GGIT_SUBMODULE_IGNORE_DEFAULT: reset to default.
- * @GGIT_SUBMODULE_IGNORE_NONE: any change or untracked == dirty.
- * @GGIT_SUBMODULE_IGNORE_UNTRACKED: dirty if tracked files change.
- * @GGIT_SUBMODULE_IGNORE_DIRTY: only dirty if HEAD moved.
- * @GGIT_SUBMODULE_IGNORE_ALL: never dirty
+ * @GGIT_SUBMODULE_IGNORE_RESET: reset to on-disk value.
+ * @GGIT_SUBMODULE_IGNORE_NONE: don't ignore any change.
+ * @GGIT_SUBMODULE_IGNORE_UNTRACKED: ignore untracked files.
+ * @GGIT_SUBMODULE_IGNORE_DIRTY: ignore changes in the working directory.
+ * @GGIT_SUBMODULE_IGNORE_ALL: never check if the submodule is dirty.
  *
  * Describes which submodules should be ignored.
  */
 typedef enum {
-	GGIT_SUBMODULE_IGNORE_DEFAULT   = -1,
-	GGIT_SUBMODULE_IGNORE_NONE      = 0,
-	GGIT_SUBMODULE_IGNORE_UNTRACKED = 1,
-	GGIT_SUBMODULE_IGNORE_DIRTY     = 2,
-	GGIT_SUBMODULE_IGNORE_ALL       = 3
+	GGIT_SUBMODULE_IGNORE_RESET     = -1,
+
+	GGIT_SUBMODULE_IGNORE_NONE      = 1,
+	GGIT_SUBMODULE_IGNORE_UNTRACKED = 2,
+	GGIT_SUBMODULE_IGNORE_DIRTY     = 3,
+	GGIT_SUBMODULE_IGNORE_ALL       = 4,
 } GgitSubmoduleIgnore;
 
 /**
@@ -693,18 +792,22 @@ typedef enum {
 
 /**
  * GgitSubmoduleUpdate:
+ * @GGIT_SUBMODULE_UPDATE_RESET: reset to on-disk value.
  * @GGIT_SUBMODULE_UPDATE_CHECKOUT: checkout the submodule.
  * @GGIT_SUBMODULE_UPDATE_REBASE: rebase the current branch onto the
  *                                commit recorded in the superproject.
  * @GGIT_SUBMODULE_UPDATE_MERGE: merge the commit recorded in the
  *                               superproject into the current branch.
+ * @GGIT_SUBMODULE_UPDATE_NONE: do not update this submodule.
  *
  * Describes how a submodule should be updated.
  */
 typedef enum {
-	GGIT_SUBMODULE_UPDATE_CHECKOUT = 0,
-	GGIT_SUBMODULE_UPDATE_REBASE   = 1,
-	GGIT_SUBMODULE_UPDATE_MERGE    = 2
+	GGIT_SUBMODULE_UPDATE_RESET    = -1,
+	GGIT_SUBMODULE_UPDATE_CHECKOUT = 1,
+	GGIT_SUBMODULE_UPDATE_REBASE   = 2,
+	GGIT_SUBMODULE_UPDATE_MERGE    = 3,
+	GGIT_SUBMODULE_UPDATE_NONE     = 4,
 } GgitSubmoduleUpdate;
 
 /**
@@ -764,9 +867,6 @@ typedef enum {
  * even if the file is in both the index and the workdir (combining #GgitStatusFlags).
  * @GGIT_STATUS_SHOW_INDEX_ONLY: only receive callbacks for files in the index.
  * @GGIT_STATUS_SHOW_WORKDIR_ONLY: only receive callbacks for files in the workdir.
- * @GGIT_STATUS_SHOW_INDEX_THEN_WORKDIR: receive callbacks first for files in
- * the index, and then in the workdir. This is equivalent to first specifying
- * #GGIT_STATUS_SHOW_INDEX_ONLY and then #GGIT_STATUS_SHOW_WORKDIR_ONLY.
  *
  * Show options for #ggit_repository_file_status_foreach. Determines which
  * files are included in the status.
@@ -775,26 +875,9 @@ typedef enum {
 typedef enum {
 	GGIT_STATUS_SHOW_INDEX_AND_WORKDIR = 0,
 	GGIT_STATUS_SHOW_INDEX_ONLY = 1,
-	GGIT_STATUS_SHOW_WORKDIR_ONLY = 2,
-	GGIT_STATUS_SHOW_INDEX_THEN_WORKDIR = 3,
+	GGIT_STATUS_SHOW_WORKDIR_ONLY = 2
 } GgitStatusShow;
 
-/**
- * GgitBranchesCallback:
- * @branch_name: the branch name.
- * @branch_type: a #GgitBranchType.
- * @user_data: (closure): user-supplied data.
- *
- * The type of the callback functions for retrieving the branches
- * in a #GgitRepository. See ggit_repository_branches_foreach().
- *
- * Returns: 0 to go for the next branch or a #GgitError in case there was an error.
- *
- */
-typedef gint (* GgitBranchesCallback) (const gchar    *branch_name,
-                                       GgitBranchType  branch_type,
-                                       gpointer        user_data);
-
 /**
  * GgitConfigCallback:
  * @entry: a #GgitConfigEntry.
@@ -859,9 +942,7 @@ typedef gint (* GgitDiffFileCallback) (GgitDiffDelta *delta,
 /**
  * GgitDiffHunkCallback:
  * @delta: a #GgitDiffDelta.
- * @range: a #GgitDiffRange.
- * @header: (array length=header_len) (element-type guint8): the header.
- * @header_len: the header length.
+ * @hunk: a #GgitDiffHunk.
  * @user_data: (closure): user-supplied data.
  *
  * Called for each hunk.
@@ -869,18 +950,14 @@ typedef gint (* GgitDiffFileCallback) (GgitDiffDelta *delta,
  * Returns: 0 to go continue or a #GgitError in case there was an error.
  */
 typedef gint (* GgitDiffHunkCallback) (GgitDiffDelta *delta,
-                                       GgitDiffRange *range,
-                                       const gchar   *header,
-                                       gsize          header_len,
+                                       GgitDiffHunk  *hunk,
                                        gpointer       user_data);
 
 /**
  * GgitDiffLineCallback:
  * @delta: a #GgitDiffDelta.
- * @range: a #GgitDiffRange.
- * @line_type: a #GgitDiffLineType.
- * @content: (array length=content_len) (element-type guint8): the content.
- * @content_len: the content length.
+ * @hunk: a #GgitDiffHunk.
+ * @line: a #GgitDiffLine.
  * @user_data: (closure): user-supplied data.
  *
  * Called for each line.
@@ -888,12 +965,33 @@ typedef gint (* GgitDiffHunkCallback) (GgitDiffDelta *delta,
  * Returns: 0 to go continue or a #GgitError in case there was an error.
  */
 typedef gint (* GgitDiffLineCallback) (GgitDiffDelta    *delta,
-                                       GgitDiffRange    *range,
-                                       GgitDiffLineType  line_type,
-                                       const gchar      *content,
-                                       gsize             content_len,
+                                       GgitDiffHunk     *hunk,
+                                       GgitDiffLine     *line,
                                        gpointer          user_data);
 
+/*
+ * FIXME: request docs for this to libgit2
+ */
+typedef gint (* GgitDiffSimilarityMetricFileSignatureCallback) (GgitDiffFile *file,
+                                                                const gchar  *fullpath,
+                                                                gpointer     *out,
+                                                                gpointer      user_data);
+
+
+typedef gint (* GgitDiffSimilarityMetricBufferSignatureCallback) (GgitDiffFile *file,
+                                                                  const gchar  *buf,
+                                                                  gsize         buflen,
+                                                                  gpointer     *out,
+                                                                  gpointer      user_data);
+
+typedef void (* GgitDiffSimilarityMetricFreeSignatureCallback) (gpointer signature,
+                                                                gpointer user_data);
+
+typedef gint (* GgitDiffSimilarityMetricSimilarityCallback) (gint     *score,
+                                                             gpointer  signature_a,
+                                                             gpointer  signature_b,
+                                                             gpointer  user_data);
+
 /**
  * GgitReferencesNameCallback:
  * @name: the name of the reference
